@@ -6,7 +6,7 @@ from .utils import geometry, interpolate, spline_geometry, resample
 
 class Straightener(object):
     """Straighten a warped object by resampling along skeleton
-    
+
     Attributes:
         img (array): Input image
         skeleton (list): Point sequence of skeleton which have no branch
@@ -19,24 +19,36 @@ class Straightener(object):
         super(Straightener, self).__init__()
         self.img = img
         self.skeleton = skeleton  # skeleton is a point sequence(list)
-        self.widths = [width/1.8+5 for width in widths]
+        self.widths = widths
 
         # Pipeline:
-        self.warp_img()
+        self.fit_spline()
+        self.straighten()
 
-    def warp_img(self):
-        spine_tck = interpolate.fit_spline(
+    def fit_spline(self):
+        # sample_widths are the widths between skeleton and contour
+        sample_widths = [width/1.8+5 for width in self.widths]
+        self.spine_tck = interpolate.fit_spline(
             [[y, x] for x, y in self.skeleton], smoothing=None)
         x_vals = np.linspace(0, 1, len(self.skeleton))
-        width_tck = interpolate.fit_nonparametric_spline(
-            x_vals, self.widths, smoothing=None)
+        self.width_tck = interpolate.fit_nonparametric_spline(
+            x_vals, sample_widths, smoothing=None)
+
+    def straighten(self):
+        overlay_width = int(max(self.widths) * 1.2)
         self.img_straightened = resample.warp_image_to_standard_width(
-            self.img, spine_tck, width_tck, width_tck, 600)
+            self.img,
+            self.spine_tck,
+            self.width_tck,
+            self.width_tck,
+            overlay_width)
         self.mask_straightened = resample.make_mask_for_sampled_spline(
             self.img_straightened.shape[0],
             self.img_straightened.shape[1],
-            width_tck)
+            self.width_tck)
         self.img_straightened[~self.mask_straightened] = 0
+        self.img_straightened = self.img_straightened.transpose()[::-1]
+        self.mask_straightened = self.mask_straightened.transpose()[::-1]
         return self.img_straightened
 
 
